export type Memo = {
    type?: string
    format?: string
    data?: string
}

export type Signature = {signature: string, signer: PublicKey}

export type Environment = {
    msg: {
        sender: Address,
        value: number,
        data: XrpTransaction,
        rawTx: string
    }
}

export type Transition<Model> = {
    call: keyof Model,
    params: any[]
}

export type ArgumentType = 'String' | 'Amount' | 'TxHash' | 'Boolean' | 'any'
export type ReturnType = ArgumentType | 'Void'
export type MutableStateOperation = 'ARRAY_PUSH' | 'ARRAY_UNSHIFT' | 'ARRAY_SHIFT' | 'ARRAY_POP' | 'VALUE_SET' | 'VALUE_DELETE'
export const MutableStateOperationStrings = ['ARRAY_PUSH', 'ARRAY_UNSHIFT', 'ARRAY_SHIFT', 'ARRAY_POP', 'VALUE_SET', 'VALUE_DELETE']
export type ArgumentDefiniton = {
    type: ArgumentType | string[],
    name: string
}
export type ContractFunctionSignature<Of = any> = {
    name: keyof Of
    argTypes: ArgumentDefiniton[]
    returnType: ReturnType
    documentation?: string,
    modifier?: Modifier[]
}

export type Modifier = "OWNER_ONLY" | "PAYABLE"
export type TransferListener = (transfer : { _from: Address, _to: Address, _value: Amount}) => void 
export type ApprovalListener = (approval : { _from: Address, _spender: Address, _value: Amount}) => void 

export type Address = string
export type Secret = string
export type PublicKey = string
export type Amount = number
export type TxHash = string

export type XrpTransaction = {
    hash: TxHash,
    sender: Address,
    receiver: Address,
    value: Amount,
    fee: Amount,
    ledger_index: number
}